Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Caffe2JobLister ¶
type Caffe2JobLister interface {
// List lists all Caffe2Jobs in the indexer.
List(selector labels.Selector) (ret []*v1alpha1.Caffe2Job, err error)
// Caffe2Jobs returns an object that can list and get Caffe2Jobs.
Caffe2Jobs(namespace string) Caffe2JobNamespaceLister
Caffe2JobListerExpansion
}
Caffe2JobLister helps list Caffe2Jobs.
func NewCaffe2JobLister ¶
func NewCaffe2JobLister(indexer cache.Indexer) Caffe2JobLister
NewCaffe2JobLister returns a new Caffe2JobLister.
type Caffe2JobListerExpansion ¶
type Caffe2JobListerExpansion interface{}
Caffe2JobListerExpansion allows custom methods to be added to Caffe2JobLister.
type Caffe2JobNamespaceLister ¶
type Caffe2JobNamespaceLister interface {
// List lists all Caffe2Jobs in the indexer for a given namespace.
List(selector labels.Selector) (ret []*v1alpha1.Caffe2Job, err error)
// Get retrieves the Caffe2Job from the indexer for a given namespace and name.
Get(name string) (*v1alpha1.Caffe2Job, error)
Caffe2JobNamespaceListerExpansion
}
Caffe2JobNamespaceLister helps list and get Caffe2Jobs.
type Caffe2JobNamespaceListerExpansion ¶
type Caffe2JobNamespaceListerExpansion interface{}
Caffe2JobNamespaceListerExpansion allows custom methods to be added to Caffe2JobNamespaceLister.
Click to show internal directories.
Click to hide internal directories.